%global majorver 1
%global minorver 28
%global patchver 1

%ifarch %{java_arches}
%global JAVA 1
%else
%global JAVA 0
%endif

Summary:  Static cluster configuration database
Name:     genders
Version:  %{majorver}.%{minorver}.%{patchver}
Release:  4%{?dist}
License:  GPLv2
URL:      https://github.com/chaos/genders
Source0:   https://github.com/chaos/genders/archive/genders-%{majorver}-%{minorver}-%{patchver}.tar.gz
Patch3000:   %{name}-1.18-shebang.patch
BuildRequires:  gcc-c++, gcc, bison, flex, autoconf

%description
Genders is a static cluster configuration database used for cluster
configuration management.  It is used by a variety of tools and
scripts for management of large clusters.  The genders database is
typically replicated on every node of the cluster. It describes the
layout and configuration of the cluster so that tools and scripts can
sense the variations of cluster nodes. By abstracting this information
into a plain text file, it becomes possible to change the
configuration of a cluster by modifying only one file.

%package compat
Summary: Compatibility library 
BuildRequires: perl-devel
BuildRequires: perl-generators
BuildRequires: perl(ExtUtils::MakeMaker)
BuildArch: noarch

%description compat
Genders API that is compatible with earlier releases of genders.

%package perl
Summary: Perl libraries
BuildRequires: perl(ExtUtils::MakeMaker)
BuildRequires: perl(Config)

%description perl
Genders API bindings for perl.

%if %{JAVA}
%package javadoc
Summary: Java Documentation
BuildRequires: java-devel

%description javadoc
Genders API Documentation for java.

%package java-devel
Summary: Java Development libraries
Requires: %{name}-java = %{version}-%{release}

%description java-devel
Genders API bindings for java.

%package java
Summary: Java libraries
BuildRequires: java-devel
BuildRequires: make

%description java
Genders API bindings for java.
%endif

%global __provides_exclude_from ^(.%{perl_vendorarch}/*\\.so)$

%package -n libgenders
Summary: Genders libraries

%description -n libgenders
Genders API for C.

%package -n libgenders-devel
Summary: Genders development libraries
Requires: libgenders = %{version}-%{release}

%description -n libgenders-devel
Genders development headers and libraries for C.

%package -n libgendersplusplus
Summary: Genders libraries for C++
Requires: libgenders = %{version}-%{release}

%description -n libgendersplusplus
Genders API for C++.

%package -n libgendersplusplus-devel
Summary: Genders development libraries
Requires: libgenders-devel = %{version}-%{release}
Requires: libgendersplusplus = %{version}-%{release}

%description -n libgendersplusplus-devel
Genders development headers and libraries for C++.



%prep
%autosetup -p1 -n %{name}-%{name}-%{majorver}-%{minorver}-%{patchver}



%build
%if %{JAVA}
export CPPFLAGS='-I/usr/lib/jvm/java/include -I/usr/lib/jvm/java/include/linux -I../../../src/libgenders'
%else
export CPPFLAGS='-I../../../src/libgenders'
%endif
%configure \
    --with-perl-extensions \
    --with-perl-vendor-arch \
%if %{JAVA}
    --with-java-extensions \
%else
    --without-java-extensions \
%endif
    --without-python-extensions \
    --with-cplusplus-extensions \
    --with-extension-destdir="%{buildroot}"
%{make_build}



%install
rm -rf %{buildroot}
%{make_install}

rm -f %{buildroot}/%{_libdir}/*.la
rm -f %{buildroot}/%{_libdir}/*.a
chmod +w %{buildroot}/%{perl_vendorarch}/auto/Lib%{name}/Lib%{name}.so
rm -f %{buildroot}/%{perl_vendorarch}/auto/Lib%{name}/Lib%{name}.bs
rm -f %{buildroot}/%{perl_vendorarch}/auto/Lib%{name}/.packlist
mkdir -p %{buildroot}/%{_libexecdir}

mkdir -p %{buildroot}/%{_jnidir}

%if %{JAVA}
mv %{buildroot}/%{_datarootdir}/java/Genders.jar %{buildroot}/%{_jnidir}/
%endif



%post -n libgenders -p /sbin/ldconfig
%postun -n libgenders -p /sbin/ldconfig
%post -n libgendersplusplus -p /sbin/ldconfig
%postun -n libgendersplusplus -p /sbin/ldconfig

%if %{JAVA}
%post -n genders-java -p /sbin/ldconfig
%postun -n genders-java -p /sbin/ldconfig
%endif



%files
%license COPYING
%doc README NEWS ChangeLog DISCLAIMER DISCLAIMER.UC TUTORIAL genders.sample
%{_mandir}/man1/*
%{_mandir}/man3/genders.3*
%{_bindir}/*

%files -n libgenders
%license COPYING 
%doc DISCLAIMER DISCLAIMER.UC
%{_libdir}/libgenders.so.0*
%{_mandir}/man3/libgenders.3*

%files -n libgenders-devel
%license COPYING
%doc DISCLAIMER DISCLAIMER.UC
%{_mandir}/man3/genders_*
%{_includedir}/genders.h
%{_libdir}/libgenders.so

%files -n libgendersplusplus
%license COPYING 
%doc DISCLAIMER DISCLAIMER.UC
%{_libdir}/libgendersplusplus.so.2*

%files -n libgendersplusplus-devel
%license COPYING
%doc DISCLAIMER DISCLAIMER.UC
%{_libdir}/libgendersplusplus.so
%{_includedir}/gendersplusplus*

%files perl
%license COPYING
%doc DISCLAIMER DISCLAIMER.UC
%{_mandir}/man3/Libgenders*
%{_mandir}/man3/Genders*
%{perl_vendorarch}/*

%if %{JAVA}
%files java-devel
%license COPYING
%doc DISCLAIMER DISCLAIMER.UC
%{_libdir}/libGendersjni.so

%files java
%license COPYING
%doc DISCLAIMER DISCLAIMER.UC
%{_libdir}/libGendersjni.so.*
%{_jnidir}/Genders.jar

%files javadoc
%license COPYING
%doc DISCLAIMER DISCLAIMER.UC
%{_docdir}/%{name}-%{majorver}.%{minorver}-javadoc
%endif

%files compat
%license COPYING
%doc DISCLAIMER DISCLAIMER.UC
%{_mandir}/man3/gendlib*
%{_usr}/lib/genders/*



%changelog
* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.28.1-4
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.28.1-3
- Rebuilt for OpenCloudOS Stream 23

* Mon Mar 27 2023 Zhao Zhen <jeremiazhao@tencent.com> - 1.28.1-2
- trimed formatting

* Mon Mar 27 2023 Zhao Zhen <jeremiazhao@tencent.com> - 1.28.1-1
- initial
